import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_certificatemanager._jsii
import aws_cdk.aws_cloudfront._jsii
import aws_cdk.aws_cloudfront_origins._jsii
import aws_cdk.aws_cognito._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.core._jsii
import aws_cdk.custom_resources._jsii
import cloudcomponents.cdk_lambda_at_edge_pattern._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@cloudcomponents/cdk-cloudfront-authorization",
    "1.38.0",
    __name__[0:-6],
    "cdk-cloudfront-authorization@1.38.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
